@@ -92,7 +92,9 @@ class StorageInterface(object):
         """
         raise NotImplementedError()
 
-    def list_files(self, path=None, filter=None, recursive=True, force_refresh=False):
+    def list_files(
+        self, path=None, filter=None, recursive=True, level=0, force_refresh=False
+    ):
         """
         List all files in storage starting at ``path``. If ``recursive`` is set to True (the default), also dives into
         subfolders.
@@ -628,7 +630,9 @@ class LocalFileStorage(StorageInterface):
         folder_path = os.path.join(path, name)
         return os.path.exists(folder_path) and os.path.isdir(folder_path)
 
-    def list_files(self, path=None, filter=None, recursive=True, force_refresh=False):
+    def list_files(
+        self, path=None, filter=None, recursive=True, level=0, force_refresh=False
+    ):
         if path:
             path = self.sanitize_path(to_unicode(path))
             base = self.path_in_storage(path)
@@ -647,6 +651,15 @@ class LocalFileStorage(StorageInterface):
                 result[key] = node
             return result
 
+        def strip_grandchildren(nodes):
+            result = {}
+            for key, node in nodes.items():
+                if node["type"] == "folder":
+                    node = copy.copy(node)
+                    node["children"] = strip_children(node["children"])
+                result[key] = node
+            return result
+
         def apply_filter(nodes, filter_func):
             result = {}
             for key, node in nodes.items():
@@ -654,14 +667,17 @@ class LocalFileStorage(StorageInterface):
                     if node["type"] == "folder":
                         node = copy.copy(node)
                         node["children"] = apply_filter(
-                            node.get("children", []), filter_func
+                            node.get("children", {}), filter_func
                         )
                     result[key] = node
             return result
 
         result = self._list_folder(path, base=base, force_refresh=force_refresh)
         if not recursive:
-            result = strip_children(result)
+            if level > 0:
+                result = strip_grandchildren(result)
+            else:
+                result = strip_children(result)
         if callable(filter):
             result = apply_filter(result, filter)
         return result
