@@ -5,9 +5,8 @@
  * To change this template use File | Settings | File Templates.
  */
 
-
-GCODE.renderer = (function(){
-// ***** PRIVATE ******
+GCODE.renderer = (function () {
+    // ***** PRIVATE ******
     var canvas;
     var ctx;
 
@@ -15,12 +14,14 @@ GCODE.renderer = (function(){
     var lineWidthFactor = 1 / 2.8;
 
     var zoomFactorDelta = 0.4;
-    var gridStep=10;
+    var gridStep = 10;
     var ctxHeight, ctxWidth;
-    var prevX=0, prevY=0;
+    var prevX = 0,
+        prevY = 0;
     var pixelRatio = window.devicePixelRatio || 1;
 
-    var layerNumStore, progressStore={from: 0, to: -1};
+    var layerNumStore,
+        progressStore = {from: 0, to: -1};
     var lastX, lastY;
     var dragStart;
     var scaleFactor = 1.1;
@@ -65,16 +66,20 @@ GCODE.renderer = (function(){
 
         onViewportChange: undefined,
         onDragStart: undefined, // Cancellable (return false)
-        onDrag: undefined,      // Cancellable (return false)
+        onDrag: undefined, // Cancellable (return false)
         onDragStop: undefined
     };
 
-    var offsetModelX = 0, offsetModelY = 0;
-    var offsetBedX = 0, offsetBedY = 0;
-    var scaleX = 1, scaleY = 1;
+    var offsetModelX = 0,
+        offsetModelY = 0;
+    var offsetBedX = 0,
+        offsetBedY = 0;
+    var scaleX = 1,
+        scaleY = 1;
     var speeds = [];
     var speedsByLayer = {};
-    var currentInvertX = false, currentInvertY = false;
+    var currentInvertX = false,
+        currentInvertY = false;
 
     function notifyIfViewportChanged() {
         if (viewportChanged) {
@@ -84,30 +89,53 @@ GCODE.renderer = (function(){
             viewportChanged = false;
         }
     }
-    
-    var reRender = function(){
+
+    var reRender = function () {
         if (!model) return;
 
-        log.debug("Rerendering layer " + layerNumStore + " of " + model.length + " with " + GCODE.renderer.getLayerNumSegments(layerNumStore) + " segments");
+        log.debug(
+            "Rerendering layer " +
+                layerNumStore +
+                " of " +
+                model.length +
+                " with " +
+                GCODE.renderer.getLayerNumSegments(layerNumStore) +
+                " segments"
+        );
 
         notifyIfViewportChanged();
 
-        var p1 = ctx.transformedPoint(0,0);
-        var p2 = ctx.transformedPoint(canvas.width,canvas.height);
-        ctx.clearRect(p1.x,p1.y,p2.x-p1.x,p2.y-p1.y);
+        var p1 = ctx.transformedPoint(0, 0);
+        var p2 = ctx.transformedPoint(canvas.width, canvas.height);
+        ctx.clearRect(p1.x, p1.y, p2.x - p1.x, p2.y - p1.y);
 
         drawGrid();
         drawBoundingBox();
         if (model && model.length) {
             if (layerNumStore < model.length) {
-                if (renderOptions['showNextLayer'] && layerNumStore < model.length - 1) {
-                    drawLayer(layerNumStore + 1, 0, GCODE.renderer.getLayerNumSegments(layerNumStore + 1), true);
+                if (renderOptions["showNextLayer"] && layerNumStore < model.length - 1) {
+                    drawLayer(
+                        layerNumStore + 1,
+                        0,
+                        GCODE.renderer.getLayerNumSegments(layerNumStore + 1),
+                        true
+                    );
                 }
-                if (renderOptions['showCurrentLayer'] && layerNumStore < model.length) {
-                    drawLayer(layerNumStore, 0, GCODE.renderer.getLayerNumSegments(layerNumStore), true);
+                if (renderOptions["showCurrentLayer"] && layerNumStore < model.length) {
+                    drawLayer(
+                        layerNumStore,
+                        0,
+                        GCODE.renderer.getLayerNumSegments(layerNumStore),
+                        true
+                    );
                 }
-                if (renderOptions['showPreviousLayer'] && layerNumStore > 0) {
-                    drawLayer(layerNumStore - 1, 0, GCODE.renderer.getLayerNumSegments(layerNumStore - 1), true);
+                if (renderOptions["showPreviousLayer"] && layerNumStore > 0) {
+                    drawLayer(
+                        layerNumStore - 1,
+                        0,
+                        GCODE.renderer.getLayerNumSegments(layerNumStore - 1),
+                        true
+                    );
                 }
                 drawLayer(layerNumStore, progressStore.from, progressStore.to);
             } else {
@@ -116,52 +144,59 @@ GCODE.renderer = (function(){
         }
     };
 
-    function trackTransforms(ctx){
-        var svg = document.createElementNS("http://www.w3.org/2000/svg",'svg');
+    function trackTransforms(ctx) {
+        var svg = document.createElementNS("http://www.w3.org/2000/svg", "svg");
         var xform = svg.createSVGMatrix();
-        ctx.getTransform = function(){ return xform; };
+        ctx.getTransform = function () {
+            return xform;
+        };
 
         var savedTransforms = [];
         var save = ctx.save;
-        ctx.save = function(){
-            savedTransforms.push(xform.translate(0,0));
+        ctx.save = function () {
+            savedTransforms.push(xform.translate(0, 0));
             return save.call(ctx);
         };
         var restore = ctx.restore;
-        ctx.restore = function(){
+        ctx.restore = function () {
             xform = savedTransforms.pop();
             viewportChanged = true;
             return restore.call(ctx);
         };
 
         var scale = ctx.scale;
-        ctx.scale = function(sx,sy){
-            xform = xform.scaleNonUniform(sx,sy);
+        ctx.scale = function (sx, sy) {
+            xform = xform.scaleNonUniform(sx, sy);
             viewportChanged = true;
-            return scale.call(ctx,sx,sy);
+            return scale.call(ctx, sx, sy);
         };
         var rotate = ctx.rotate;
-        ctx.rotate = function(radians){
-            xform = xform.rotate(radians*180/Math.PI);
+        ctx.rotate = function (radians) {
+            xform = xform.rotate((radians * 180) / Math.PI);
             viewportChanged = true;
-            return rotate.call(ctx,radians);
+            return rotate.call(ctx, radians);
         };
         var translate = ctx.translate;
-        ctx.translate = function(dx,dy){
-            xform = xform.translate(dx,dy);
+        ctx.translate = function (dx, dy) {
+            xform = xform.translate(dx, dy);
             viewportChanged = true;
-            return translate.call(ctx,dx,dy);
+            return translate.call(ctx, dx, dy);
         };
         var transform = ctx.transform;
-        ctx.transform = function(a,b,c,d,e,f){
+        ctx.transform = function (a, b, c, d, e, f) {
             var m2 = svg.createSVGMatrix();
-            m2.a=a; m2.b=b; m2.c=c; m2.d=d; m2.e=e; m2.f=f;
+            m2.a = a;
+            m2.b = b;
+            m2.c = c;
+            m2.d = d;
+            m2.e = e;
+            m2.f = f;
             xform = xform.multiply(m2);
             viewportChanged = true;
-            return transform.call(ctx,a,b,c,d,e,f);
+            return transform.call(ctx, a, b, c, d, e, f);
         };
         var setTransform = ctx.setTransform;
-        ctx.setTransform = function(a,b,c,d,e,f){
+        ctx.setTransform = function (a, b, c, d, e, f) {
             xform.a = a;
             xform.b = b;
             xform.c = c;
@@ -169,109 +204,127 @@ GCODE.renderer = (function(){
             xform.e = e;
             xform.f = f;
             viewportChanged = true;
-            return setTransform.call(ctx,a,b,c,d,e,f);
+            return setTransform.call(ctx, a, b, c, d, e, f);
         };
-        var pt  = svg.createSVGPoint();
-        ctx.transformedPoint = function(x,y){
-            pt.x=x; pt.y=y;
+        var pt = svg.createSVGPoint();
+        ctx.transformedPoint = function (x, y) {
+            pt.x = x;
+            pt.y = y;
             return pt.matrixTransform(xform.inverse());
-        }
+        };
     }
 
-
-    var  startCanvas = function() {
+    var startCanvas = function () {
         var jqueryCanvas = $(renderOptions["container"]);
         //jqueryCanvas.css("background-color", renderOptions["bgColorOffGrid"]);
         canvas = jqueryCanvas[0];
 
-        ctx = canvas.getContext('2d');
+        ctx = canvas.getContext("2d");
         canvas.style.height = canvas.height + "px";
         canvas.style.width = canvas.width + "px";
         canvas.height = canvas.height * pixelRatio;
         canvas.width = canvas.width * pixelRatio;
         ctxHeight = canvas.height;
         ctxWidth = canvas.width;
-        lastX = ctxWidth/2;
-        lastY = ctxHeight/2;
+        lastX = ctxWidth / 2;
+        lastY = ctxHeight / 2;
         ctx.lineWidth = 2 * lineWidthFactor;
-        ctx.lineCap = 'round';
+        ctx.lineCap = "round";
         trackTransforms(ctx);
 
-        ctx.scale(1,-1); // Invert y-axis
+        ctx.scale(1, -1); // Invert y-axis
 
         // dragging => translating
-        canvas.addEventListener('mousedown', function(event){
-            document.body.style.mozUserSelect = document.body.style.webkitUserSelect = document.body.style.userSelect = 'none';
+        canvas.addEventListener(
+            "mousedown",
+            function (event) {
+                document.body.style.mozUserSelect = document.body.style.webkitUserSelect = document.body.style.userSelect =
+                    "none";
 
-            // remember starting point of dragging gesture
-            lastX = (event.offsetX || (event.pageX - canvas.offsetLeft)) * pixelRatio;
-            lastY = (event.offsetY || (event.pageY - canvas.offsetTop)) * pixelRatio;
+                // remember starting point of dragging gesture
+                lastX = (event.offsetX || event.pageX - canvas.offsetLeft) * pixelRatio;
+                lastY = (event.offsetY || event.pageY - canvas.offsetTop) * pixelRatio;
 
-            var pt = ctx.transformedPoint(lastX, lastY);
-            if (!renderOptions["onDragStart"] || (renderOptions["onDragStart"](pt) !== false))
-              dragStart = pt;
-        }, false);
+                var pt = ctx.transformedPoint(lastX, lastY);
+                if (
+                    !renderOptions["onDragStart"] ||
+                    renderOptions["onDragStart"](pt) !== false
+                )
+                    dragStart = pt;
+            },
+            false
+        );
 
-        canvas.addEventListener('mousemove', function(event){
-            // save current mouse coordinates
-            lastX = (event.offsetX || (event.pageX - canvas.offsetLeft)) * pixelRatio;
-            lastY = (event.offsetY || (event.pageY - canvas.offsetTop)) * pixelRatio;
+        canvas.addEventListener(
+            "mousemove",
+            function (event) {
+                // save current mouse coordinates
+                lastX = (event.offsetX || event.pageX - canvas.offsetLeft) * pixelRatio;
+                lastY = (event.offsetY || event.pageY - canvas.offsetTop) * pixelRatio;
 
-            // mouse movement => dragged
-            if (dragStart !== undefined) {
-                // translate
-                var pt = ctx.transformedPoint(lastX,lastY);
+                // mouse movement => dragged
+                if (dragStart !== undefined) {
+                    // translate
+                    var pt = ctx.transformedPoint(lastX, lastY);
 
-                if (renderOptions["onDrag"] && (renderOptions["onDrag"](pt) === false))
-                    return;
+                    if (renderOptions["onDrag"] && renderOptions["onDrag"](pt) === false)
+                        return;
 
-                ctx.translate(pt.x - dragStart.x, pt.y - dragStart.y);
-                reRender();
+                    ctx.translate(pt.x - dragStart.x, pt.y - dragStart.y);
+                    reRender();
 
-                renderOptions["centerViewport"] = false;
-                renderOptions["zoomInOnModel"] = false;
-                renderOptions["zoomInOnBed"] = false;
-                offsetModelX = 0;
-                offsetModelY = 0;
-                offsetBedX = 0;
-                offsetBedY = 0;
-                scaleX = 1;
-                scaleY = 1;
+                    renderOptions["centerViewport"] = false;
+                    renderOptions["zoomInOnModel"] = false;
+                    renderOptions["zoomInOnBed"] = false;
+                    offsetModelX = 0;
+                    offsetModelY = 0;
+                    offsetBedX = 0;
+                    offsetBedY = 0;
+                    scaleX = 1;
+                    scaleY = 1;
 
-                if (renderOptions["onInternalOptionChange"] !== undefined) {
-                    renderOptions["onInternalOptionChange"]({
-                        centerViewport: false,
-                        moveModel: false,
-                        zoomInOnModel: false,
-                        zoomInOnBed: false
-                    });
+                    if (renderOptions["onInternalOptionChange"] !== undefined) {
+                        renderOptions["onInternalOptionChange"]({
+                            centerViewport: false,
+                            moveModel: false,
+                            zoomInOnModel: false,
+                            zoomInOnBed: false
+                        });
+                    }
                 }
-            }
-        }, false);
+            },
+            false
+        );
 
-        canvas.addEventListener('mouseup', function(event){
-            // reset dragStart
-            dragStart = undefined;
+        canvas.addEventListener(
+            "mouseup",
+            function (event) {
+                // reset dragStart
+                dragStart = undefined;
 
-            if (renderOptions["onDragStop"]) {
-                var x = (event.offsetX || (event.pageX - canvas.offsetLeft)) * pixelRatio;
-                var y = (event.offsetY || (event.pageY - canvas.offsetTop)) * pixelRatio;
-                renderOptions["onDragStop"](ctx.transformedPoint(x,y));
-            }
-        }, false);
+                if (renderOptions["onDragStop"]) {
+                    var x =
+                        (event.offsetX || event.pageX - canvas.offsetLeft) * pixelRatio;
+                    var y =
+                        (event.offsetY || event.pageY - canvas.offsetTop) * pixelRatio;
+                    renderOptions["onDragStop"](ctx.transformedPoint(x, y));
+                }
+            },
+            false
+        );
 
         // mouse wheel => zooming
-        var zoom = function(clicks){
+        var zoom = function (clicks) {
             // focus on last mouse position prior to zoom
             var pt = ctx.transformedPoint(lastX, lastY);
-            ctx.translate(pt.x,pt.y);
+            ctx.translate(pt.x, pt.y);
 
             // determine zooming factor and perform zoom
-            var factor = Math.pow(scaleFactor,clicks);
-            ctx.scale(factor,factor);
+            var factor = Math.pow(scaleFactor, clicks);
+            ctx.scale(factor, factor);
 
             // return to old position
-            ctx.translate(-pt.x,-pt.y);
+            ctx.translate(-pt.x, -pt.y);
 
             // render
             reRender();
@@ -293,7 +346,7 @@ GCODE.renderer = (function(){
                 });
             }
         };
-        var handleScroll = function(event){
+        var handleScroll = function (event) {
             var delta;
 
             // determine zoom direction & delta
@@ -306,13 +359,13 @@ GCODE.renderer = (function(){
 
             return event.preventDefault() && false;
         };
-        canvas.addEventListener('DOMMouseScroll',handleScroll,false);
-        canvas.addEventListener('mousewheel',handleScroll,false);
+        canvas.addEventListener("DOMMouseScroll", handleScroll, false);
+        canvas.addEventListener("mousewheel", handleScroll, false);
     };
 
-    var drawGrid = function() {
+    var drawGrid = function () {
         ctx.translate(offsetBedX, offsetBedY);
-        if(renderOptions["bed"]["circular"]) {
+        if (renderOptions["bed"]["circular"]) {
             drawCircularGrid();
         } else {
             drawRectangularGrid();
@@ -320,7 +373,7 @@ GCODE.renderer = (function(){
         ctx.translate(-offsetBedX, -offsetBedY);
     };
 
-    var drawRectangularGrid = function() {
+    var drawRectangularGrid = function () {
         var x, y;
         var width = renderOptions["bed"]["x"];
         var height = renderOptions["bed"]["y"];
@@ -394,7 +447,7 @@ GCODE.renderer = (function(){
         ctx.stroke();
     };
 
-    var drawCircularGrid = function() {
+    var drawCircularGrid = function () {
         var i;
 
         ctx.strokeStyle = renderOptions["colorGrid"];
@@ -430,7 +483,7 @@ GCODE.renderer = (function(){
         ctx.beginPath();
         for (i = 0; i <= r; i += gridStep) {
             var x = i;
-            var y = Math.sqrt(r*r - x*x);
+            var y = Math.sqrt(r * r - x * x);
 
             ctx.moveTo(x, -1 * y);
             ctx.lineTo(x, y);
@@ -447,7 +500,7 @@ GCODE.renderer = (function(){
         ctx.stroke();
     };
 
-    var drawBoundingBox = function() {
+    var drawBoundingBox = function () {
         if (!modelInfo) return;
 
         var minX, minY, width, height;
@@ -485,7 +538,7 @@ GCODE.renderer = (function(){
         ctx.setLineDash([1, 0]);
     };
 
-    var drawTriangle = function(centerX, centerY, length, up) {
+    var drawTriangle = function (centerX, centerY, length, up) {
         /*
          *             (cx,cy)
          *                *             ^
@@ -532,8 +585,18 @@ GCODE.renderer = (function(){
         ctx.lineJoin = origLineJoin;
     };
 
-    var drawLayer = function(layerNum, fromProgress, toProgress, isNotCurrentLayer){
-        log.trace("Drawing layer " + layerNum + " from " + fromProgress + " to " + toProgress + " (current: " + !isNotCurrentLayer + ")");
+    var drawLayer = function (layerNum, fromProgress, toProgress, isNotCurrentLayer) {
+        log.trace(
+            "Drawing layer " +
+                layerNum +
+                " from " +
+                fromProgress +
+                " to " +
+                toProgress +
+                " (current: " +
+                !isNotCurrentLayer +
+                ")"
+        );
 
         var i;
 
@@ -560,17 +623,15 @@ GCODE.renderer = (function(){
             // previous layer exists, use last x/y as prevX/prevY
             prevX = undefined;
             prevY = undefined;
-            var prevModelLayer = model[layerNum-1];
-            for (i = prevModelLayer.length-1; i >= 0; i--) {
+            var prevModelLayer = model[layerNum - 1];
+            for (i = prevModelLayer.length - 1; i >= 0; i--) {
                 if (prevX === undefined && prevModelLayer[i].x !== undefined) {
                     prevX = prevModelLayer[i].x;
-                    if (prevY !== undefined)
-                        break;
+                    if (prevY !== undefined) break;
                 }
                 if (prevY === undefined && prevModelLayer[i].y !== undefined) {
                     prevY = prevModelLayer[i].y;
-                    if (prevX !== undefined)
-                        break;
+                    if (prevX !== undefined) break;
                 }
             }
         }
@@ -586,8 +647,14 @@ GCODE.renderer = (function(){
 
         // alpha value (100% if current layer is being rendered, 30% otherwise)
         // Note - If showing currently layer as preview - also render it at 30% and draw the progress over the top at 100%
-        var alpha = (renderOptions['showNextLayer'] || renderOptions['showCurrentLayer'] || renderOptions['showPreviousLayer']) && isNotCurrentLayer ? 0.3 : 1.0;
-        
+        var alpha =
+            (renderOptions["showNextLayer"] ||
+                renderOptions["showCurrentLayer"] ||
+                renderOptions["showPreviousLayer"]) &&
+            isNotCurrentLayer
+                ? 0.3
+                : 1.0;
+
         var colorLine = {};
         var colorMove = {};
         var colorRetract = {};
@@ -599,7 +666,11 @@ GCODE.renderer = (function(){
                 var lineColor = renderOptions["colorLine"][tool];
                 if (lineColor === undefined) lineColor = renderOptions["colorLine"][0];
                 var shade = tool * 0.15;
-                rv = colorLine[tool] = pusher.color(lineColor).shade(shade).alpha(alpha).html();
+                rv = colorLine[tool] = pusher
+                    .color(lineColor)
+                    .shade(shade)
+                    .alpha(alpha)
+                    .html();
             }
             return rv;
         }
@@ -608,7 +679,11 @@ GCODE.renderer = (function(){
             var rv = colorMove[tool];
             if (rv === undefined) {
                 var shade = tool * 0.15;
-                rv = colorMove[tool] = pusher.color(renderOptions["colorMove"]).shade(shade).alpha(alpha).html();
+                rv = colorMove[tool] = pusher
+                    .color(renderOptions["colorMove"])
+                    .shade(shade)
+                    .alpha(alpha)
+                    .html();
             }
             return rv;
         }
@@ -617,7 +692,11 @@ GCODE.renderer = (function(){
             var rv = colorRetract[tool];
             if (rv === undefined) {
                 var shade = tool * 0.15;
-                rv = colorRetract[tool] = pusher.color(renderOptions["colorRetract"]).shade(shade).alpha(alpha).html();
+                rv = colorRetract[tool] = pusher
+                    .color(renderOptions["colorRetract"])
+                    .shade(shade)
+                    .alpha(alpha)
+                    .html();
             }
             return rv;
         }
@@ -626,14 +705,18 @@ GCODE.renderer = (function(){
             var rv = colorRestart[tool];
             if (rv === undefined) {
                 var shade = tool * 0.15;
-                rv = colorRestart[tool] = pusher.color(renderOptions["colorRestart"]).shade(shade).alpha(alpha).html();
+                rv = colorRestart[tool] = pusher
+                    .color(renderOptions["colorRestart"])
+                    .shade(shade)
+                    .alpha(alpha)
+                    .html();
             }
             return rv;
         }
 
         var prevPathType = "fill";
         function strokePathIfNeeded(newPathType, strokeStyle) {
-            if ((newPathType != prevPathType) || (newPathType == "fill")) {
+            if (newPathType != prevPathType || newPathType == "fill") {
                 if (prevPathType != "fill") {
                     ctx.stroke();
                 }
@@ -641,8 +724,8 @@ GCODE.renderer = (function(){
 
                 ctx.beginPath();
                 if (newPathType != "fill") {
-                  ctx.strokeStyle = strokeStyle;
-                  ctx.moveTo(prevX, prevY);
+                    ctx.strokeStyle = strokeStyle;
+                    ctx.moveTo(prevX, prevY);
                 }
             }
         }
@@ -650,7 +733,7 @@ GCODE.renderer = (function(){
         ctx.lineJoin = "round";
 
         for (i = fromProgress; i <= toProgress; i++) {
-            if (typeof(cmds[i]) === 'undefined') continue;
+            if (typeof cmds[i] === "undefined") continue;
             var cmd = cmds[i];
 
             if (cmd.prevX !== undefined && cmd.prevY !== undefined) {
@@ -689,27 +772,34 @@ GCODE.renderer = (function(){
                 }
 
                 strokePathIfNeeded("move", getColorMoveForTool(tool));
-                if(renderOptions["showMoves"] && !isNotCurrentLayer) {
+                if (renderOptions["showMoves"] && !isNotCurrentLayer) {
                     // move => draw line from (prevX, prevY) to (x, y) in move color
                     ctx.lineWidth = lineWidthFactor;
-                    ctx.lineTo(x,y);
+                    ctx.lineTo(x, y);
                 }
-            } else if(cmd.extrude) {
+            } else if (cmd.extrude) {
                 if (cmd.retract == 0) {
                     // no retraction => real extrusion move, use tool color to draw line
                     strokePathIfNeeded("extrude", getColorLineForTool(tool));
-                    ctx.lineWidth = renderOptions['extrusionWidth'] * lineWidthFactor;
-                    if (cmd.direction !== undefined && cmd.direction != 0){
+                    ctx.lineWidth = renderOptions["extrusionWidth"] * lineWidthFactor;
+                    if (cmd.direction !== undefined && cmd.direction != 0) {
                         var di = cmd.i;
                         var dj = cmd.j;
-                        var centerX = prevX+di;
-                        var centerY = prevY+dj;
-                        var startAngle = Math.atan2(prevY-centerY, prevX - centerX);
+                        var centerX = prevX + di;
+                        var centerY = prevY + dj;
+                        var startAngle = Math.atan2(prevY - centerY, prevX - centerX);
                         var endAngle = Math.atan2(y - centerY, x - centerX);
-                        var radius=Math.sqrt(di*di+dj*dj);
-                        ctx.arc(centerX,centerY,radius,startAngle,endAngle,cmd.direction<0); // Y-axis is inverted so direction is also inverted
+                        var radius = Math.sqrt(di * di + dj * dj);
+                        ctx.arc(
+                            centerX,
+                            centerY,
+                            radius,
+                            startAngle,
+                            endAngle,
+                            cmd.direction < 0
+                        ); // Y-axis is inverted so direction is also inverted
                     } else {
-                        ctx.lineTo(x,y);
+                        ctx.lineTo(x, y);
                     }
                 } else {
                     // we were previously retracting, now we are restarting => draw dot if configured to do so
@@ -726,22 +816,27 @@ GCODE.renderer = (function(){
             prevX = x;
             prevY = y;
         }
-        
+
         if (prevPathType != "fill") {
             ctx.stroke();
         }
 
         if (renderOptions["showHead"] && !isNotCurrentLayer) {
-            var sizeHeadSpot = renderOptions["sizeHeadSpot"] * lineWidthFactor + lineWidthFactor / 2;
+            var sizeHeadSpot =
+                renderOptions["sizeHeadSpot"] * lineWidthFactor + lineWidthFactor / 2;
             var shade = tool * 0.15;
-            ctx.fillStyle = pusher.color(renderOptions["colorHead"]).shade(shade).alpha(alpha).html();
+            ctx.fillStyle = pusher
+                .color(renderOptions["colorHead"])
+                .shade(shade)
+                .alpha(alpha)
+                .html();
             ctx.beginPath();
-            ctx.arc(prevX, prevY, sizeHeadSpot, 0, Math.PI*2, true);
+            ctx.arc(prevX, prevY, sizeHeadSpot, 0, Math.PI * 2, true);
             ctx.fill();
         }
     };
 
-    var applyOffsets = function() {
+    var applyOffsets = function () {
         var canvasCenter;
 
         // determine bed and model offsets
@@ -749,8 +844,12 @@ GCODE.renderer = (function(){
         if (renderOptions["centerViewport"] || renderOptions["zoomInOnModel"]) {
             canvasCenter = ctx.transformedPoint(canvas.width / 2, canvas.height / 2);
             if (modelInfo) {
-                offsetModelX = canvasCenter.x - (modelInfo.boundingBox.minX + modelInfo.boundingBox.maxX) / 2;
-                offsetModelY = canvasCenter.y - (modelInfo.boundingBox.minY + modelInfo.boundingBox.maxY) / 2;
+                offsetModelX =
+                    canvasCenter.x -
+                    (modelInfo.boundingBox.minX + modelInfo.boundingBox.maxX) / 2;
+                offsetModelY =
+                    canvasCenter.y -
+                    (modelInfo.boundingBox.minY + modelInfo.boundingBox.maxY) / 2;
             } else {
                 offsetModelX = 0;
                 offsetModelY = 0;
@@ -758,11 +857,24 @@ GCODE.renderer = (function(){
             offsetBedX = 0;
             offsetBedY = 0;
         } else if (modelInfo && renderOptions["moveModel"]) {
-            offsetModelX = (renderOptions["bed"]["x"] / 2 - (modelInfo.boundingBox.minX + modelInfo.boundingBox.maxX) / 2);
-            offsetModelY = (renderOptions["bed"]["y"] / 2 - (modelInfo.boundingBox.minY + modelInfo.boundingBox.maxY) / 2);
-            offsetBedX = -1 * (renderOptions["bed"]["x"] / 2 - (modelInfo.boundingBox.minX + modelInfo.boundingBox.maxX) / 2);
-            offsetBedY = -1 * (renderOptions["bed"]["y"] / 2 - (modelInfo.boundingBox.minY + modelInfo.boundingBox.maxY) / 2);
-        } else if (renderOptions["bed"]["circular"] || renderOptions["bed"]["centeredOrigin"]) {
+            offsetModelX =
+                renderOptions["bed"]["x"] / 2 -
+                (modelInfo.boundingBox.minX + modelInfo.boundingBox.maxX) / 2;
+            offsetModelY =
+                renderOptions["bed"]["y"] / 2 -
+                (modelInfo.boundingBox.minY + modelInfo.boundingBox.maxY) / 2;
+            offsetBedX =
+                -1 *
+                (renderOptions["bed"]["x"] / 2 -
+                    (modelInfo.boundingBox.minX + modelInfo.boundingBox.maxX) / 2);
+            offsetBedY =
+                -1 *
+                (renderOptions["bed"]["y"] / 2 -
+                    (modelInfo.boundingBox.minY + modelInfo.boundingBox.maxY) / 2);
+        } else if (
+            renderOptions["bed"]["circular"] ||
+            renderOptions["bed"]["centeredOrigin"]
+        ) {
             canvasCenter = ctx.transformedPoint(canvas.width / 2, canvas.height / 2);
             offsetModelX = canvasCenter.x;
             offsetModelY = canvasCenter.y;
@@ -777,9 +889,9 @@ GCODE.renderer = (function(){
         if (ctx) ctx.translate(offsetModelX, offsetModelY);
     };
 
-    var applyZoom = function() {
+    var applyZoom = function () {
         // get middle of canvas
-        var pt = ctx.transformedPoint(canvas.width/2,canvas.height/2);
+        var pt = ctx.transformedPoint(canvas.width / 2, canvas.height / 2);
 
         // get current transform
         var transform = ctx.getTransform();
@@ -797,11 +909,16 @@ GCODE.renderer = (function(){
             var width = modelInfo.boundingBox.maxX - modelInfo.boundingBox.minX;
             var length = modelInfo.boundingBox.maxY - modelInfo.boundingBox.minY;
 
-            var scaleF = width > length ? (canvas.width - 10) / width : (canvas.height - 10) / length;
+            var scaleF =
+                width > length
+                    ? (canvas.width - 10) / width
+                    : (canvas.height - 10) / length;
             if (transform.a && transform.d) {
-                scaleX = scaleF / transform.a * (renderOptions["invertAxes"]["x"] ? -1 : 1);
-                scaleY = scaleF / transform.d * (renderOptions["invertAxes"]["y"] ? 1 : -1);
-                ctx.translate(pt.x,pt.y);
+                scaleX =
+                    (scaleF / transform.a) * (renderOptions["invertAxes"]["x"] ? -1 : 1);
+                scaleY =
+                    (scaleF / transform.d) * (renderOptions["invertAxes"]["y"] ? 1 : -1);
+                ctx.translate(pt.x, pt.y);
                 ctx.scale(scaleX, scaleY);
                 ctx.translate(-pt.x, -pt.y);
             }
@@ -812,7 +929,7 @@ GCODE.renderer = (function(){
         }
     };
 
-    var applyInversion = function() {
+    var applyInversion = function () {
         var width = canvas.width - 10;
         var height = canvas.height - 10;
 
@@ -837,19 +954,22 @@ GCODE.renderer = (function(){
         currentInvertY = invertY;
     };
 
-// ***** PUBLIC *******
+    // ***** PUBLIC *******
     return {
-        init: function(){
+        init: function () {
             startCanvas();
             initialized = true;
             var bedWidth = renderOptions["bed"]["x"];
             var bedHeight = renderOptions["bed"]["y"];
-            if(renderOptions["bed"]["circular"]) {
+            if (renderOptions["bed"]["circular"]) {
                 bedWidth = bedHeight = renderOptions["bed"]["r"] * 2;
             }
 
             // Ratio of bed to canvas viewport
-            var viewportRatio = Math.min((canvas.width - 10) / bedWidth, (canvas.height - 10) / bedHeight);
+            var viewportRatio = Math.min(
+                (canvas.width - 10) / bedWidth,
+                (canvas.height - 10) / bedHeight
+            );
 
             // Apply initial translation to center the bed in the viewport
             var translationX, translationY;
@@ -858,12 +978,14 @@ GCODE.renderer = (function(){
                 translationY = canvas.height / 2;
             } else {
                 translationX = (canvas.width - bedWidth * viewportRatio) / 2;
-                translationY = bedHeight * viewportRatio + (canvas.height - bedHeight * viewportRatio) / 2;
+                translationY =
+                    bedHeight * viewportRatio +
+                    (canvas.height - bedHeight * viewportRatio) / 2;
             }
             ctx.translate(translationX, -translationY);
 
             ctx.scale(viewportRatio, viewportRatio);
-            
+
             offsetModelX = 0;
             offsetModelY = 0;
             offsetBedX = 0;
@@ -872,23 +994,33 @@ GCODE.renderer = (function(){
             // Scaling to apply to move lines and extrusion/retraction markers
             lineWidthFactor = 1 / viewportRatio;
         },
-        setOption: function(options){
+        setOption: function (options) {
             var mustRefresh = false;
             var dirty = false;
             for (var opt in options) {
-                if (!renderOptions.hasOwnProperty(opt) || !options.hasOwnProperty(opt)) continue;
+                if (!renderOptions.hasOwnProperty(opt) || !options.hasOwnProperty(opt))
+                    continue;
                 if (options[opt] === undefined) continue;
                 if (renderOptions[opt] == options[opt]) continue;
 
                 dirty = true;
                 renderOptions[opt] = options[opt];
-                if ($.inArray(opt, ["moveModel", "centerViewport", "zoomInOnModel", "bed", "invertAxes", "onViewportChange"]) > -1) {
+                if (
+                    $.inArray(opt, [
+                        "moveModel",
+                        "centerViewport",
+                        "zoomInOnModel",
+                        "bed",
+                        "invertAxes",
+                        "onViewportChange"
+                    ]) > -1
+                ) {
                     mustRefresh = true;
                 }
             }
 
             if (!dirty) return;
-            if(initialized) {
+            if (initialized) {
                 if (mustRefresh) {
                     this.refresh();
                 } else {
@@ -896,32 +1028,32 @@ GCODE.renderer = (function(){
                 }
             }
         },
-        getOptions: function(){
+        getOptions: function () {
             return renderOptions;
         },
-        debugGetModel: function(){
+        debugGetModel: function () {
             return model;
         },
-        render: function(layerNum, fromProgress, toProgress){
+        render: function (layerNum, fromProgress, toProgress) {
             if (!initialized) this.init();
-            
+
             layerNumStore = layerNum;
             progressStore.from = fromProgress;
             progressStore.to = toProgress;
 
             reRender();
         },
-        getModelNumLayers: function(){
+        getModelNumLayers: function () {
             return model ? model.length : 1;
         },
-        getLayerNumSegments: function(layer){
-            if(model){
-                return model[layer]?model[layer].length:1;
-            }else{
+        getLayerNumSegments: function (layer) {
+            if (model) {
+                return model[layer] ? model[layer].length : 1;
+            } else {
                 return 1;
             }
         },
-        clear: function() {
+        clear: function () {
             offsetModelX = 0;
             offsetModelY = 0;
             offsetBedX = 0;
@@ -934,7 +1066,7 @@ GCODE.renderer = (function(){
 
             this.doRender([], 0);
         },
-        doRender: function(mdl, layerNum){
+        doRender: function (mdl, layerNum) {
             model = mdl;
             modelInfo = undefined;
 
@@ -958,20 +1090,19 @@ GCODE.renderer = (function(){
 
             this.render(layerNum, 0, toProgress);
         },
-        refresh: function(layerNum) {
+        refresh: function (layerNum) {
             if (layerNum === undefined) layerNum = layerNumStore;
             this.doRender(model, layerNum);
         },
-        getZ: function(layerNum){
-            if(!model || !model[layerNum]){
-                return '-1';
+        getZ: function (layerNum) {
+            if (!model || !model[layerNum]) {
+                return "-1";
             }
             var cmds = model[layerNum];
-            for(var i = 0; i < cmds.length; i++){
-                if(cmds[i].prevZ !== undefined) return cmds[i].prevZ;
+            for (var i = 0; i < cmds.length; i++) {
+                if (cmds[i].prevZ !== undefined) return cmds[i].prevZ;
             }
-            return '-1';
+            return "-1";
         }
-
-}
-}());
+    };
+})();
